package com.malk.lanyun.schedule;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.lang.UUID;
import cn.hutool.http.HttpUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.fastjson.JSONObject;
import com.malk.lanyun.entity.Budget;
import com.malk.lanyun.listener.BudgetListener;
import com.malk.lanyun.listener.BudgetListenerForProject;
import com.malk.lanyun.service.FService;
import com.malk.lanyun.service.SyncAssetsService;
import com.malk.lanyun.service.TimerService;
import com.malk.server.aliwork.YDConf;
import com.malk.server.aliwork.YDParam;
import com.malk.service.aliwork.YDClient;
import com.malk.utils.UtilMap;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @EnableScheduling 开启定时任务 [配置参考McScheduleTask]
 */
@Slf4j
@Configuration
@EnableScheduling
@ConditionalOnProperty(name = {"budget.scheduling"})
public class BudgetUploadTask {

    @Autowired
    private YDClient ydClient;

    /**
     * 每3分钟执行一次
     */
    @Scheduled(cron = "20 0/5 * * * ?")
    public void syncDingTalkFailedList() {
        log.info("{}开始执行预算导入程序...", LocalDateTime.now());
        List<Map> list=(List<Map>) ydClient.queryData(YDParam.builder().formUuid("FORM-DCBC92CE004244569BC22A759FB7D2853GEA").appType("APP_ERBDTFS82HOVBPL3NFH0")
                        .systemToken("RRB66F91T97H1WN89QZYC47PKLZO2ZQOUMOQLP").searchCondition(JSONObject.toJSONString(UtilMap.map("selectField_m5f4hrlq","待导入")))
                        .pageSize(1).build(),
                YDConf.FORM_QUERY.retrieve_list_all).getData();
        log.info("查询到待导入数据条数：{}",list.size());
        for (Map map:list){
            System.out.println(map);
            Map formData=UtilMap.getMap(map,"formData");
            boolean isUpdateDe=UtilMap.getString(formData,"selectField_m4cbvkth").equals("是");
            String formInstanceId=UtilMap.getString(map,"formInstanceId");
            String id= UUID.randomUUID().toString();
            String fileName = "/home/"+id+".xlsx";
            Map upMap=UtilMap.map("selectField_m5f4hrlq, selectField_m5f4hrlr","导入中",(isUpdateDe?"导入中":"无需处理"));
            updateState(formInstanceId,upMap);
            upMap=new HashMap();
            String url=ydClient.convertTemporaryUrl(UtilMap.getString(formData,"textField_m4718ynv"));
            HttpUtil.downloadFile(url,fileName);
            try {
                EasyExcel.read(fileName, Budget.class, new BudgetListener(ydClient,UtilMap.getString(formData,"textField_lw8vg19m"),
                        UtilMap.getString(formData,"textField_lw7sg8ho"),UtilMap.getString(formData,"dateField_lvxkipwr"),formInstanceId)).sheet().headRowNumber(3).doRead();
            }catch (Exception e){
                e.printStackTrace();
                upMap.put("selectField_m5f4hrlq","导入失败");
                upMap.put("textField_m5f4hrlv","导入出错！错误信息："+e.getMessage());
            }
            if(isUpdateDe){
                try {
                    EasyExcel.read(fileName, Budget.class, new BudgetListenerForProject(ydClient,UtilMap.getString(formData,"textField_lrr3rg6h"),UtilMap.getString(formData,"textField_lw7sg8ho"))).sheet().headRowNumber(3).doRead();
                    upMap.put("selectField_m5f4hrlr","导入成功");
                    upMap.put("textField_m5f4hrlw","导入完成");
                }catch (Exception e){
                    e.printStackTrace();
                    upMap.put("selectField_m5f4hrlr","导入失败");
                    upMap.put("textField_m5f4hrlw","导入出错！错误信息："+e.getMessage());
                }
            }
            updateState(formInstanceId,upMap);
            FileUtil.del(fileName);
        }
        log.info("{}预算导入程序执行完成！",LocalDateTime.now());
    }

    private void updateState(String formInstanceId,Map upMap){
        ydClient.operateData(YDParam.builder().formInstanceId(formInstanceId).appType("APP_ERBDTFS82HOVBPL3NFH0")
                .systemToken("RRB66F91T97H1WN89QZYC47PKLZO2ZQOUMOQLP").updateFormDataJson(JSONObject.toJSONString(upMap)).build(), YDConf.FORM_OPERATION.update);
    }

}