package com.malk.lanyun.schedule;

import com.malk.lanyun.service.NCService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

@Slf4j
@Configuration
@EnableScheduling
@ConditionalOnProperty(name = {"nc.scheduling"})
public class NCTask {
    @Autowired
    NCService ncService;

    /**
     * 每月1日凌晨4点跑批NC生产成本
     */
    @Scheduled(cron = "0 0 4 * * ?")
    void productCosts() {
        log.info("开始跑批更新NC生产成本");
        ncService.getNcInfo();
    }

    /**
     * 每月1日凌晨4点30跑批NC物耗成本
     */
    @Scheduled(cron = "0 30 4 * * ?")
    void materialCost() {
        log.info("开始跑批更新NC生产成本");
        ncService.getNcCgInfo();
    }
    /**
     * 每月1日凌晨5点跑批NC大业主生产成本
     */
    @Scheduled(cron = "0 0 5 * * ?")
    void bigProductCosts() {
        log.info("开始跑批更新NC大业主生产成本");
        ncService.getNcCost();
    }
    /**
     * 每月1日凌晨5点30跑批NC-部门费用达成明细
     */
    @Scheduled(cron = "0 30 5 * * ?")
    void departmentCost() {
        log.info("开始跑批更新NC-部门费用达成明细");
        ncService.getNcCollection();
    }
    /**
     * 每月1日凌晨6点跑批NC供应商付款
     */
    @Scheduled(cron = "0 0 6 * * ?")
    void supplierPay() {
        log.info("开始跑批更新NC供应商付款");
        ncService.getSupplierPay();
    }
    /**
     * 每月1日凌晨6点跑批NC同步宜搭
     */
    @Scheduled(cron = "0 0 0/2 * * ?")
    void ncToYiDa() {
        ncService.ncToYiDa();
    }
}
