package com.malk.lanyun.schedule;

import com.malk.lanyun.service.FService;
import com.malk.lanyun.service.SyncAssetsService;
import com.malk.lanyun.service.TimerService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import java.time.LocalDate;
import java.util.Date;

/**
 * @EnableScheduling 开启定时任务 [配置参考McScheduleTask]
 */
@Slf4j
@Configuration
@EnableScheduling
@ConditionalOnProperty(name = {"spel.scheduling"})
public class ScheduleTask {

    @Autowired
    private TimerService timerService;

    @Autowired
    private SyncAssetsService syncAssetsService;

    @Autowired
    private FService fService;

    /**
     * 每月1日凌晨1点自动执行
     */
    @Scheduled(cron = "0 0 1 1 * ?")
    public void syncDingTalkFailedList() {
        timerService.updateYuedudinge();
        log.info("定时方法执行时间 :" + new Date());
    }
    /**
     * 每月1日凌晨1点自动执行
     */
    @Scheduled(cron = "0 0 2 1 * ?")
    public void syncDingTalkFailedList2() {
        timerService.updateYuedudinge();
        log.info("定时方法执行时间 :" + new Date());
    }

    /**
     * 每月16日凌晨6点30自动执行更新项目点档案子表产值预估
     */
    @Scheduled(cron = "0 30 6 16 * ?")
    public void updateOutputPredict() {
        log.info("定时方法执行时间 :" + new Date());
        timerService.updateOutputPredict();
        timerService.updateYearPredict();
    }

    /**
     * 每月1日凌晨0点自动执行更新业主产值每月累计
     */
    @Scheduled(cron = "0 0 0 1 * ?")
    public void bigOwnerOutPut() {
        timerService.updateBigOut();
        log.info("定时方法执行时间 :" + new Date());
    }

    /**
     * 每月1日上午8点自动发起风控绩效流程
     */
    @Scheduled(cron = "0 0 8 1 * ?")
    public void monthRiskMerits() {
        timerService.monthRiskMerits();
        log.info("定时方法执行时间 :" + new Date());
    }

    /**
     * 各项目经营分析每月1日上午3点30自动插入数据库
     */
    @Scheduled(cron = "0 30 3 1 * ?")
    void insertAnalysisList(){
        timerService.insertAnalysisList();
    }

    /**
     * 每月1号 凌晨3点跑批计算净值
     */
    @Scheduled(cron = "0 0 3 1 * ?")
    void synAssetsItem(){
        syncAssetsService.SynAssetsItem();
    }

    /**
     * 每月最后一天跑批入职人员
     */
    @Scheduled(cron = "0 30 23 28-31 * ?")
    void SynDingNumber(){
        // 获取当前日期
        LocalDate today = LocalDate.now();

        // 获取当月的最后一天
        LocalDate lastDayOfMonth = today.withDayOfMonth(today.lengthOfMonth());
        //判断是否相等
        if (today.equals(lastDayOfMonth)){
            syncAssetsService.SynDingUserNumber();
        }
    }

    /**
     * 每月最后一天跑批离职人员
     */
    @Scheduled(cron = "0 30 22 28-31 * ?")
    void SynDingLeaveOffice(){
        // 获取当前日期
        LocalDate today = LocalDate.now();

        // 获取当月的最后一天
        LocalDate lastDayOfMonth = today.withDayOfMonth(today.lengthOfMonth());
        //判断是否相等
        if (today.equals(lastDayOfMonth)){
            syncAssetsService.SynDingLeaveUserNumber();
        }

    }

    /**
     * 每日凌晨0点30自动执行更新项目点档案本周出库情况
     */
    @Scheduled(cron = "0 30 12 * * 5")
    public void projectUnshippedTask() {
        log.info("项目点档案本周出库情况执行时间 :" + new Date());
        timerService.projectUnshipped();
    }

    /**
     * 每日上午2点30更新月度入离职
     */
    @Scheduled(cron = "0 30 2 * * ?")
    void monthPersonnelTask(){
        timerService.monthPersonnelMatters();
    }
    /**
     * 每月10号上午9点同步催款函
     */
    @Scheduled(cron = "0 0 9 10 * ?")
    void syncCallLettersTask(){
        log.info("开始同步催款函");
        fService.syncCallLetters();
    }

    /**
     * 每2小时全量同步账龄表
     */
    @Scheduled(cron = "0 0 0/2 * * ?")
    void syncAgingTask(){
        log.info("全量同步账龄表");
        fService.syncAgingSchedule();
        try {
            Thread.sleep(3000);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
        syncDeleteAgingTask();
    }

    /**
     * 每2小时15分删除账龄表重复uuid
     */
//    @Scheduled(cron = "0 15 0/2 * * ?")
    private void syncDeleteAgingTask(){
        log.info("删除账龄表重复uuid");
        fService.syncDeleteAgingTask();
    }


    /**
     * 每2小时全量同步账龄表
     */
//    @Scheduled(cron = "0 0 0/2 * * ?")
    @Scheduled(cron = "0 0 10 ? * SAT")
    void updateUseCar(){
        log.info("每周六上午10点更新每日用车");
        timerService.updateUseCar();
    }
}